==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/LogStreamSettingsAws.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AwsRegion;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Specifies the configuration for the &#x60;aws_eventbridge&#x60; Log Stream type. This configuration can&#39;t be
 * modified after creation.
 */
@ApiModel(description = "Specifies the configuration for the `aws_eventbridge` Log Stream type. This configuration can't be modified after creation.")
@JsonPropertyOrder({ LogStreamSettingsAws.JSON_PROPERTY_ACCOUNT_ID,
        LogStreamSettingsAws.JSON_PROPERTY_EVENT_SOURCE_NAME, LogStreamSettingsAws.JSON_PROPERTY_REGION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class LogStreamSettingsAws implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ACCOUNT_ID = "accountId";
    private String accountId;

    public static final String JSON_PROPERTY_EVENT_SOURCE_NAME = "eventSourceName";
    private String eventSourceName;

    public static final String JSON_PROPERTY_REGION = "region";
    private AwsRegion region;

    public LogStreamSettingsAws() {
    }

    public LogStreamSettingsAws accountId(String accountId) {

        this.accountId = accountId;
        return this;
    }

    /**
     * Your AWS account ID
     *
     * @return accountId
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(example = "123456789012", required = true, value = "Your AWS account ID")
    @JsonProperty(JSON_PROPERTY_ACCOUNT_ID)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getAccountId() {
        return accountId;
    }

    @JsonProperty(JSON_PROPERTY_ACCOUNT_ID)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setAccountId(String accountId) {
        this.accountId = accountId;
    }

    public LogStreamSettingsAws eventSourceName(String eventSourceName) {

        this.eventSourceName = eventSourceName;
        return this;
    }

    /**
     * An alphanumeric name (no spaces) to identify this event source in AWS EventBridge
     *
     * @return eventSourceName
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(example = "your-event-source-name", required = true, value = "An alphanumeric name (no spaces) to identify this event source in AWS EventBridge")
    @JsonProperty(JSON_PROPERTY_EVENT_SOURCE_NAME)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getEventSourceName() {
        return eventSourceName;
    }

    @JsonProperty(JSON_PROPERTY_EVENT_SOURCE_NAME)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setEventSourceName(String eventSourceName) {
        this.eventSourceName = eventSourceName;
    }

    public LogStreamSettingsAws region(AwsRegion region) {

        this.region = region;
        return this;
    }

    /**
     * Get region
     *
     * @return region
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "")
    @JsonProperty(JSON_PROPERTY_REGION)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public AwsRegion getRegion() {
        return region;
    }

    @JsonProperty(JSON_PROPERTY_REGION)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setRegion(AwsRegion region) {
        this.region = region;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LogStreamSettingsAws logStreamSettingsAws = (LogStreamSettingsAws) o;
        return Objects.equals(this.accountId, logStreamSettingsAws.accountId)
                && Objects.equals(this.eventSourceName, logStreamSettingsAws.eventSourceName)
                && Objects.equals(this.region, logStreamSettingsAws.region);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(accountId, eventSourceName, region);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LogStreamSettingsAws {\n");
        sb.append("    accountId: ").append(toIndentedString(accountId)).append("\n");
        sb.append("    eventSourceName: ").append(toIndentedString(eventSourceName)).append("\n");
        sb.append("    region: ").append(toIndentedString(region)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/LogStreamSettingsAws.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AwsRegion;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Specifies the configuration for the &#x60;aws_eventbridge&#x60; Log Stream type. This configuration can&#39;t be
 * modified after creation.
 */
@ApiModel(description = "Specifies the configuration for the `aws_eventbridge` Log Stream type. This configuration can't be modified after creation.")
@JsonPropertyOrder({ LogStreamSettingsAws.JSON_PROPERTY_ACCOUNT_ID,
        LogStreamSettingsAws.JSON_PROPERTY_EVENT_SOURCE_NAME, LogStreamSettingsAws.JSON_PROPERTY_REGION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class LogStreamSettingsAws implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ACCOUNT_ID = "accountId";
    private String accountId;

    public static final String JSON_PROPERTY_EVENT_SOURCE_NAME = "eventSourceName";
    private String eventSourceName;

    public static final String JSON_PROPERTY_REGION = "region";
    private AwsRegion region;

    public LogStreamSettingsAws() {
    }

    public LogStreamSettingsAws accountId(String accountId) {

        this.accountId = accountId;
        return this;
    }

    /**
     * Your AWS account ID
     *
     * @return accountId
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(example = "123456789012", required = true, value = "Your AWS account ID")
    @JsonProperty(JSON_PROPERTY_ACCOUNT_ID)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getAccountId() {
        return accountId;
    }

    @JsonProperty(JSON_PROPERTY_ACCOUNT_ID)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setAccountId(String accountId) {
        this.accountId = accountId;
    }

    public LogStreamSettingsAws eventSourceName(String eventSourceName) {

        this.eventSourceName = eventSourceName;
        return this;
    }

    /**
     * An alphanumeric name (no spaces) to identify this event source in AWS EventBridge
     *
     * @return eventSourceName
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(example = "your-event-source-name", required = true, value = "An alphanumeric name (no spaces) to identify this event source in AWS EventBridge")
    @JsonProperty(JSON_PROPERTY_EVENT_SOURCE_NAME)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getEventSourceName() {
        return eventSourceName;
    }

    @JsonProperty(JSON_PROPERTY_EVENT_SOURCE_NAME)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setEventSourceName(String eventSourceName) {
        this.eventSourceName = eventSourceName;
    }

    public LogStreamSettingsAws region(AwsRegion region) {

        this.region = region;
        return this;
    }

    /**
     * Get region
     *
     * @return region
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "")
    @JsonProperty(JSON_PROPERTY_REGION)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public AwsRegion getRegion() {
        return region;
    }

    @JsonProperty(JSON_PROPERTY_REGION)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setRegion(AwsRegion region) {
        this.region = region;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LogStreamSettingsAws logStreamSettingsAws = (LogStreamSettingsAws) o;
        return Objects.equals(this.accountId, logStreamSettingsAws.accountId)
                && Objects.equals(this.eventSourceName, logStreamSettingsAws.eventSourceName)
                && Objects.equals(this.region, logStreamSettingsAws.region);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(accountId, eventSourceName, region);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LogStreamSettingsAws {\n");
        sb.append("    accountId: ").append(toIndentedString(accountId)).append("\n");
        sb.append("    eventSourceName: ").append(toIndentedString(eventSourceName)).append("\n");
        sb.append("    region: ").append(toIndentedString(region)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
